@@ -2,7 +2,7 @@
  * @file
  *
  * This file is a part of KDE project
- * <a href="https://projects.kde.org/projects/extragear/libs/libmediawiki">libmediawiki</a>
+ * <a href="https://commits.kde.org/libmediawiki">libmediawiki</a>
  *
  * @date   2011-03-22
  * @brief  a MediaWiki C++ interface for KDE
@@ -30,10 +30,10 @@
 #ifndef TEST_EDIT_H
 #define TEST_EDIT_H
 
-#include <QtCore/QObject>
-#include <QtTest/QtTest>
+#include <QObject>
+#include <QtTest>
 
-#include <KCoreAddons/KJob>
+#include <KJob>
 
 #include "mediawiki.h"
 #include "edit.h"
@@ -105,7 +105,7 @@ private Q_SLOTS:
         QTest::addColumn<QString>("senario");
         QTest::addColumn<Edit*>("job");
 
-        Edit* const e1 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e1 = new Edit( *m_mediaWiki, nullptr);
         e1->setSection(QStringLiteral("new"));
         e1->setSummary(QStringLiteral("Hello World") );
         e1->setPageName( QStringLiteral("Talk:Main Page") );
@@ -118,7 +118,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e1;
 
-        Edit* const e2 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e2 = new Edit( *m_mediaWiki, nullptr);
         e2->setSection(QStringLiteral("new"));
         e2->setSummary(QStringLiteral("Hello World"));
         e2->setPageName( QStringLiteral("Talk:Main Page") );
@@ -131,7 +131,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e2;
 
-        Edit* const e3 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e3 = new Edit( *m_mediaWiki, nullptr);
         e3->setSection(QStringLiteral("new"));
         e3->setSummary(QStringLiteral("Hello World"));
         e3->setPageName( QStringLiteral("Talk:Main Page") );
@@ -144,7 +144,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e3;
 
-        Edit* const e4 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e4 = new Edit( *m_mediaWiki, nullptr);
         e4->setSummary(QStringLiteral("Hello World"));
         e4->setPageName( QStringLiteral("Talk:Main Page") );
         e4->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -156,7 +156,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e4;
 
-        Edit* const e5 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e5 = new Edit( *m_mediaWiki, nullptr);
         e5->setSummary(QStringLiteral("Hello World"));
         e5->setPageName( QStringLiteral("Talk:Main Page") );
         e5->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -168,7 +168,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e5;
 
-        Edit* const e6 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e6 = new Edit( *m_mediaWiki, nullptr);
         e6->setSummary(QStringLiteral("Hello World"));
         e6->setPageName( QStringLiteral("Talk:Main Page") );
         e6->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -182,7 +182,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e6;
 
-        Edit* const e7 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e7 = new Edit( *m_mediaWiki, nullptr);
         e7->setSummary(QStringLiteral("Hello World"));
         e7->setPageName( QStringLiteral("Talk:Main Page") );
         e7->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -196,7 +196,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e7;
 
-        Edit* const e8 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e8 = new Edit( *m_mediaWiki, nullptr);
         e8->setSummary(QStringLiteral("Hello World"));
         e8->setPageName( QStringLiteral("Talk:Main Page") );
         e8->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -210,7 +210,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e8;
 
-        Edit* const e9 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e9 = new Edit( *m_mediaWiki, nullptr);
         e9->setSummary(QStringLiteral("Hello World"));
         e9->setPageName( QStringLiteral("Talk:Main Page") );
         e9->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -224,7 +224,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e9;
 
-        Edit* const e10 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e10 = new Edit( *m_mediaWiki, nullptr);
         e10->setSummary(QStringLiteral("Hello World"));
         e10->setPageName( QStringLiteral("Talk:Main Page") );
         e10->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -236,7 +236,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e10;
 
-        Edit* const e11 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e11 = new Edit( *m_mediaWiki, nullptr);
         e11->setSummary(QStringLiteral("Hello World"));
         e11->setPageName( QStringLiteral("Talk:Main Page") );
         e11->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -248,7 +248,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e11;
 
-        Edit* const e12 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e12 = new Edit( *m_mediaWiki, nullptr);
         e12->setSummary(QStringLiteral("Hello World"));
         e12->setPageName( QStringLiteral("Talk:Main Page") );
         e12->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -260,7 +260,7 @@ private Q_SLOTS:
                 << QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>")
                 << e12;
 
-        Edit* const e13 = new Edit( *m_mediaWiki, NULL);
+        Edit* const e13 = new Edit( *m_mediaWiki, nullptr);
         e13->setSummary(QStringLiteral("Hello World"));
         e13->setPageName( QStringLiteral("Talk:Main Page") );
         e13->setToken( QStringLiteral("cecded1f35005d22904a35cc7b736e18+\\") );
@@ -290,7 +290,7 @@ private Q_SLOTS:
             fakeserver.startAndWait();
         }
 
-        Edit* const job = new Edit(mediawiki, NULL);
+        Edit* const job = new Edit(mediawiki, nullptr);
         job->setSection(QStringLiteral("new"));
         job->setSummary(QStringLiteral("Hello World") );
         job->setPageName( QStringLiteral("Talk:Main Page") );
@@ -402,7 +402,7 @@ private Q_SLOTS:
         fakeserver.addScenario(senario);
         fakeserver.startAndWait();
 
-        Edit edit( *m_mediaWiki, NULL);
+        Edit edit( *m_mediaWiki, nullptr);
         edit.setSection(QStringLiteral("new"));
         edit.setSummary(QStringLiteral("Hello World") );
         edit.setPageName( QStringLiteral("Talk:Main Page") );
