@@ -2,7 +2,7 @@
  * @file
  *
  * This file is a part of KDE project
- * <a href="https://projects.kde.org/projects/extragear/libs/libmediawiki">libmediawiki</a>
+ * <a href="https://commits.kde.org/libmediawiki">libmediawiki</a>
  *
  * @date   2011-03-22
  * @brief  a MediaWiki C++ interface for KDE
@@ -30,10 +30,10 @@
 #ifndef TEST_LOGIN_H
 #define TEST_LOGIN_H
 
-#include <QtCore/QObject>
-#include <QtTest/QtTest>
+#include <QObject>
+#include <QtTest>
 
-#include <KCoreAddons/KJob>
+#include <KJob>
 
 #include "mediawiki.h"
 #include "login.h"
