@@ -2,7 +2,7 @@
  * @file
  *
  * This file is a part of KDE project
- * <a href="https://projects.kde.org/projects/extragear/libs/libmediawiki">libmediawiki</a>
+ * <a href="https://commits.kde.org/libmediawiki">libmediawiki</a>
  *
  * @date   2011-03-22
  * @brief  a MediaWiki C++ interface for KDE
@@ -27,16 +27,16 @@
  *
  * ============================================================ */
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QUrl>
-#include <QtTest/QTest>
+#include <QList>
+#include <QMap>
+#include <QObject>
+#include <QString>
+#include <QUrl>
+#include <QTest>
 #include <QFile>
 #include <QTextStream>
 
-#include <KCoreAddons/KJob>
+#include <KJob>
 
 #include "libmediawikitest/fakeserver.h"
 
